#ifndef SVN_VERSION_H
#define SVN_VERSION_H

#define SVN_VERSION "ff0f07ba1d01c9a8eb35ca2fa08fe5795f4532b2 [/startdir/boinc] (archlinux:/build/boinc/src/boinc [makepkg]) [Server-Release: server_release/1.x/1.x.0-3660-gff0f07ba1d01c9a8eb35ca2fa08fe5795f4532b2]"
#define GIT_REVISION 0xff0f07ba
#define GIT_DATE 1781484725
#define REPOSITORY__STARTDIR_BOINC 1

#endif
